@@ -1,4 +1,5 @@
 import defichainUtils.utils.utils as utils
+#import utils.utils as utils
 
 def decodeCustomTx(hex):
     '''
@@ -35,21 +36,23 @@ def decodeSetGovVariableHeight(hex):
     govVariable = hex[2:2+2*int(hex[:2],16)]
     hex = hex[2+2*int(hex[:2],16):]
     if utils.stringToHex('ATTRIBUTES') == govVariable:
-        if hex[:2] != '01':
-            return {
-                'error': 1,
-                'msg': 'Expected only one value in this function. Please contact package DEV.'
-            }
+        # if hex[:2] != '01':
+        #     return {
+        #         'error': 1,
+        #         'msg': 'Expected only one value in this function. Please contact package DEV.'
+        #     }
         variables = [
-            {'bytesCount': 4, 'key': None, 'type': int,'endian':None},
-            {'bytesCount': 1, 'key': 'type', 'type': str,'endian':None},
-            {'bytesCount': 1, 'key': 'typeId', 'type': int,'endian':None},
-            {'bytesCount': 4, 'key': 'key', 'type': str,'endian':'big'},
-            {'bytesCount': 4, 'key': 'keyId', 'type': int,'endian':'little'},
-            {'bytesCount': 8, 'key': 'value', 'type': int,'endian':'little'},
+            {'key':'attributes', 'type': [
+                {'bytesCount': 4, 'key': None, 'type': int,'endian':None},
+                {'bytesCount': 1, 'key': 'type', 'type': str,'endian':None},
+                {'bytesCount': 1, 'key': 'typeId', 'type': int,'endian':None},
+                {'bytesCount': 4, 'key': 'key', 'type': str,'endian':'big'},
+                {'bytesCount': 4, 'key': 'keyId', 'type': int,'endian':'little'},
+                {'bytesCount': 8, 'key': 'value', 'type': int,'endian':'little'}]
+            },
             {'bytesCount': 4, 'key': 'height', 'type': int,'endian':'little'}
         ]
-        return searchHex(variables,hex[2:])
+        return searchHex(variables,hex)
     elif utils.stringToHex('ICX_TAKERFEE_PER_BTC') == govVariable:
         # TODO: write Decoding
         pass
